package com.lifepay.pinpaddemo.activities;

import android.content.pm.PackageManager;
import android.support.v4.app.ActivityCompat;
import android.support.v4.content.ContextCompat;
import android.view.View;
import android.widget.Button;
import android.widget.RadioButton;

import com.lifepay.lib.LifePayApi;
import com.lifepay.lib.beans.TerminalType;
import com.lifepay.lib.reader.utils.PinpadBluetoothDevice;
import com.lifepay.pinpaddemo.TestData;
import com.lifepay.pinpaddemo.activities.pinpad.PinpadPaymentActivity_;
import com.lifepay.pinpaddemo.utils.ActivityUtils;
import com.lifepay.pinpaddemo.R;
import com.lifepay.pinpaddemo.activities.base.BaseFragmentActivity;
import com.lifepay.pinpaddemo.activities.base.FBaseMenuBar;
import com.lifepay.pinpaddemo.activities.pinpad.refund.PinpadRefundActivity_;

import org.androidannotations.annotations.AfterViews;
import org.androidannotations.annotations.CheckedChange;
import org.androidannotations.annotations.Click;
import org.androidannotations.annotations.EActivity;
import org.androidannotations.annotations.FragmentById;
import org.androidannotations.annotations.ViewById;

@EActivity(R.layout.activity_main)
public class MainActivity extends BaseFragmentActivity {
    private final int REQUEST_COARSE_LOCATION = 1001;

    @FragmentById
    protected FBaseMenuBar fMenuBar;

    @ViewById
    protected Button btnRefund;
    @ViewById
    protected Button btnClear;
    @ViewById
    protected RadioButton rbDspread;
    @ViewById
    protected RadioButton rbIngenico;

    @AfterViews
    protected void init() {
        fMenuBar.hideBackBtn();

        //Включение тестового режима, чтобы транзакции ходили через тестовые сервера.
        LifePayApi.getInstance().changeTestMode(context, true);
        //Если не было платежа, то кнопку возврата прячем, т.к. непонятно, что возвращать.
        if (TestData.TRANSACTION_INFO == null) {
            btnRefund.setVisibility(View.GONE);
        }
        if (TestData.TERMINAL_TYPE == TerminalType.DSPREAD_QPOS) {
            rbDspread.setChecked(true);
        } else {
            rbIngenico.setChecked(true);
        }
        updateUI();

        checkLocationAccess();
    }


    private void checkLocationAccess() {
        if (ContextCompat.checkSelfPermission(context,
                android.Manifest.permission.ACCESS_COARSE_LOCATION) != PackageManager.PERMISSION_GRANTED) {
            ActivityCompat.requestPermissions(this,
                    new String[]{android.Manifest.permission.ACCESS_COARSE_LOCATION},
                    REQUEST_COARSE_LOCATION);
        }
    }

    @Override
    public void onRequestPermissionsResult(int requestCode,
                                           String permissions[], int[] grantResults) {
        switch (requestCode) {
            case REQUEST_COARSE_LOCATION: {
                if (grantResults.length > 0
                        && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
                    return;
                }
            }
        }
        checkLocationAccess();
    }

    public void updateUI() {
        //Прячем кнопку отвязки приложения от конкретного терминала, если связанного терминала нету.
        //Библиотека запоминает конкретный терминал, после успешного подключения к терминалу
        //И в дальнейшем будет подключаться сразу к нему.
        //Не путать с сопряжением(для RP750x), которое происходит на уровне операционной системы.
        PinpadBluetoothDevice device = LifePayApi.getInstance().pinPad().getLinkedTerminal(context, TestData.TERMINAL_TYPE);
        if (device == null) {
            btnClear.setVisibility(View.GONE);
        } else {
            btnClear.setVisibility(View.VISIBLE);
            btnClear.setText("Отвязаться от "+device.name);
        }
    }

    @Click(R.id.btnPayment)
    public void onPaymentClick() {
        TestData.GENERATE_NEW_AMOUNT_AND_CLIENT_PAYMENT_ID();
        ActivityUtils.startActivity(this, PinpadPaymentActivity_.class);
    }

    @Click(R.id.btnRefund)
    public void onRefundClick() {
        ActivityUtils.startActivity(this, PinpadRefundActivity_.class);
    }

    @CheckedChange(R.id.rbDspread)
    public void onDspreadCheckedChanged(boolean checked) {
        TestData.TERMINAL_TYPE = checked ? TerminalType.DSPREAD_QPOS : TerminalType.INGENICO_RP750X;
        updateUI();
    }

    @Click(R.id.btnClear)
    public void onClearClick() {
        //Если это вызвать, то библиотека при старте транзакции предложит выбрать терминал из списка сопряженных терминалов.
        LifePayApi.getInstance().pinPad().removeLinkedDevice(this, TestData.TERMINAL_TYPE);
        btnClear.setVisibility(View.GONE);
    }

    @Click(R.id.btnTransactionList)
    public void onTransactionListClick() {
        ActivityUtils.startActivity(this, TransactionListActivity_.class);
    }

    @Override
    public void back() {

    }
}