package com.lifepay.pinpaddemo.activities.pinpad;

import android.content.Intent;
import android.view.View;
import android.widget.AdapterView;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;

import com.lifepay.pinpaddemo.R;
import com.lifepay.pinpaddemo.activities.base.BaseFragment;

import org.androidannotations.annotations.AfterViews;
import org.androidannotations.annotations.Click;
import org.androidannotations.annotations.EFragment;
import org.androidannotations.annotations.UiThread;
import org.androidannotations.annotations.ViewById;

import java.util.ArrayList;
import java.util.List;

@EFragment(R.layout.f_pinpad_bluetooth_select)
public class FPinpadBluetoothSelect extends BaseFragment {

    protected String TAG = FPinpadBluetoothSelect.class.getSimpleName();

    private String pinpad_paired_info = "Если терминал отсутствует, произведите сопряжение. Для этого нажмите на «Настройки Bluetooth», после чего вернитесь обратно в Lifepay. При возникновении трудностей, обратитесь к инструкции.";
    private String pinpad_connect_info = "Если терминал отсутствует в списке, то включите его. Если терминал уже включен, попробуйте выключить и включить его.";
    private String pinpad_paired_empty_list = "Сопряженные устройства отсутствуют. Для того, чтобы выполнить сопряжение, нажмите на «Настройки Bluetooth», после чего вернитесь обратно в Lifepay. При возникновении трудностей, обратитесь к инструкции.";
    private String pinpad_connect_empty_list = "Найденные устройства отсутствуют. Нужно включить ваш терминал. Если терминал уже включен, попробуйте выключить и включить его.";

    @ViewById
    protected TextView tvTerminalsEmpty;
    @ViewById
    protected TextView tvInfo;
    @ViewById
    protected LinearLayout llPaired;
    @ViewById
    protected ListView lwPaired;
    @ViewById
    protected Button btnSettings;

    BluetoothDeviceAdapter adapter;

    private FP750xBluetoothSelectIntf intf;

    public void setIntf(FP750xBluetoothSelectIntf intf) {
        this.intf = intf;
    }

    @AfterViews
    protected void init() {
        lwPaired.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> adapterView,
                                    View view, int i, long l) {
                adapter.updateSelectedPosition(i);
                intf.select(i);
            }
        });

        adapter = new BluetoothDeviceAdapter(context, new ArrayList<String>());
        lwPaired.setAdapter(adapter);
    }

    @Click(R.id.btnSettings)
    public void onSettingsClick() {
        Intent intentOpenBluetoothSettings = new Intent();
        intentOpenBluetoothSettings.setAction(android.provider.Settings.ACTION_BLUETOOTH_SETTINGS);
        startActivity(intentOpenBluetoothSettings);
    }

    @UiThread
    public void setNeedParing(boolean needParing) {
        if(tvTerminalsEmpty ==null)
            return;

        btnSettings.setVisibility(needParing ? View.VISIBLE : View.GONE);
        tvInfo.setText(needParing ? pinpad_paired_info : pinpad_connect_info);
        tvTerminalsEmpty.setText(needParing ? pinpad_paired_empty_list : pinpad_connect_empty_list);
    }


    @UiThread
    public void updateDevicesList(List<String> devices) {
        if(tvTerminalsEmpty ==null)
            return;
        if (devices.size() > 0) {
            adapter.clear();
            for (String str : devices) {
                adapter.insert(str, adapter.getCount());
            }
            adapter.setDeviceNames(devices);
            adapter.notifyDataSetChanged();

            tvTerminalsEmpty.setVisibility(View.GONE);
            llPaired.setVisibility(View.VISIBLE);
        } else {
            tvTerminalsEmpty.setVisibility(View.VISIBLE);
            llPaired.setVisibility(View.GONE);
        }
    }

    @Override
    public void onResume() {
        super.onResume();
        if (intf != null && this.getView() != null
                && this.getView().getVisibility() == View.GONE) intf.update();
    }

    public interface FP750xBluetoothSelectIntf {
        void select(int index);

        void update();
    }

}