package com.lifepay.pinpaddemo.utils;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.os.Handler;
import android.text.TextUtils;

import com.lifepay.lib.exception.Errors;
import com.lifepay.lib.utils.Utils;

public class UIUtilsHelper {
	protected static String TAG = UIUtilsHelper.class.getSimpleName();

	public static void showErrorMessage(Context context, String message,
			OnClickListener onClickListener) {
		if (!TextUtils.isEmpty(message))
			showAlert(context, message, onClickListener);
		else {
			String error = Errors.getErrorMessageByCode(context,
					Errors.Error.UNKNOWN_ERROR);
			showAlert(context, error, onClickListener);
		}
	}

	public static void showErrorMessage(Context context, int code,
			OnClickListener onClickListener) {
		String message = Errors.getErrorMessageByCode(context, code);
		if (message != null)
			showAlert(context, message, onClickListener);
	}

	public static void showErrorMessage(Context context, String message) {
		showErrorMessage(context, message, null);
	}

	public static void showAlert(Context context, final String message,
			OnClickListener onClickListener) {
		if (!Utils.isContextAvailable(context)) {
			return;
		}
		try {
			AlertDialog.Builder builder = new AlertDialog.Builder(context);
			builder.setMessage(message).setCancelable(false)
					.setNeutralButton("ok", onClickListener)
					.show();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public static void showAlert(Context context, int message,
			boolean cancelable, OnClickListener listenerOK) {
		if (!Utils.isContextAvailable(context)) {
			return;
		}
		try {
			AlertDialog.Builder builder = new AlertDialog.Builder(context);
			builder.setMessage(message).setCancelable(cancelable);
			builder.setPositiveButton("ok", listenerOK);
			builder.setNegativeButton("cancel",
					new OnClickListener() {
						public void onClick(DialogInterface dialog, int which) {
							try {
								dialog.dismiss();
							} catch (IllegalArgumentException ex) {
								;
							}
						}
					}).show();

		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public static void showAlert(Context context, int message,
			boolean cancalable, OnClickListener listenerOk,
			OnClickListener listenerCancel) {
		if (!Utils.isContextAvailable(context)) {
			return;
		}
		try {
			AlertDialog.Builder builder = new AlertDialog.Builder(context);
			builder.setMessage(message).setCancelable(cancalable);
			builder.setPositiveButton("ok", listenerOk);
			builder.setNegativeButton("cancel", listenerCancel)
					.show();

		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public static void showAlert(Context context, final int message) {
		showAlert(context, context.getString(message));
	}

	public static void showAlert(Context context, final String message) {
		showAlert(context, message, new OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				try {
					dialog.dismiss();
				} catch (IllegalArgumentException ex) {
					;
				}
			}
		});
	}

	public static void showAlert(Context context, final Handler handler,
			final String message) {
		showAlert(context, message, new OnClickListener() {
			public void onClick(DialogInterface dialog, int which) {
				try {
					dialog.dismiss();
				} catch (IllegalArgumentException ex) {
					;
				}
				if (handler != null)
					handler.sendEmptyMessage(0);
			}
		});
	}

	public static void showAlert(Context context, final int message,
			OnClickListener onClickListener) {
		showAlert(context, context.getString(message), onClickListener);
	}

}
